#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
const update_notifier_1 = __importDefault(require("update-notifier"));
const create_1 = __importDefault(require("../lib/commands/create"));
const add_1 = __importDefault(require("../lib/commands/add"));
const list_1 = __importDefault(require("../lib/commands/list"));
const delete_1 = __importDefault(require("../lib/commands/delete"));
const config_1 = __importDefault(require("../lib/commands/config"));
const pkg = require("../../package.json");
commander_1.program.version(pkg.version);
commander_1.program
    .command("config <target>")
    .description("config template records path")
    .action(async function (target) {
    await (0, config_1.default)(target);
});
commander_1.program
    .command("create [target]")
    .description("create a new project")
    .option("-t, --templatePath [value]", "init with local template")
    .option("-d, --destPath [value]", "destination path for generating")
    .action(async function (target, options) {
    if (options.templatePath) {
        options.templatePath = path_1.default.resolve(options.templatePath);
    }
    else if (target) {
        options.templatePath = target;
    }
    await (0, create_1.default)(options);
});
commander_1.program
    .command("add")
    .description("add new template")
    .action(async function () {
    await (0, add_1.default)();
});
commander_1.program
    .command("delete")
    .alias("del")
    .description("delete a template from records")
    .action(function (options) {
    (0, delete_1.default)();
});
commander_1.program
    .command("list")
    .alias("ls")
    .description("list all templates")
    .action(function () {
    (0, list_1.default)();
});
commander_1.program.on("--help", () => {
    console.log(`  Usages:
    ${chalk_1.default.gray("# create a new project by someone template")}
    $ inix 
  `);
});
commander_1.program.on("command:*", function () {
    console.error("Invalid command: %s\nSee --help for a list of available commands.", commander_1.program.args.join(" "));
    commander_1.program.outputHelp();
    checkLatestVersion();
    process.exit(1);
});
process.on("uncaughtException", handleError);
process.on("unhandledRejection", handleError);
function handleError(err) {
    console.log(err);
    checkLatestVersion();
    process.exit(1);
}
function help() {
    checkLatestVersion();
    commander_1.program.parse(process.argv);
    if (commander_1.program.args.length < 1)
        return commander_1.program.help();
}
function checkLatestVersion() {
    var notifier = (0, update_notifier_1.default)({ pkg });
    if (notifier.update) {
        console.log(`Update available: ${notifier.update.latest}`);
    }
}
help();
