"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGitUrl = exports.downloadRepo = exports.updateTemplateData = exports.getTemplateRecords = void 0;
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const child_process_1 = require("child_process");
const os_1 = require("os");
const tmp_1 = __importDefault(require("tmp"));
const tplPath = path_1.default.join((0, os_1.homedir)(), ".inix", "template.json");
fs_extra_1.default.ensureFileSync(tplPath);
const getTemplateRecords = function () {
    try {
        const tpls = fs_extra_1.default.readJsonSync(tplPath);
        return tpls;
    }
    catch (e) {
        return {};
    }
};
exports.getTemplateRecords = getTemplateRecords;
const updateTemplateData = function (tplData) {
    if (typeof tplData === "object") {
        tplData = JSON.stringify(tplData, null, 2);
    }
    fs_extra_1.default.writeFileSync(tplPath, tplData);
};
exports.updateTemplateData = updateTemplateData;
const downloadRepo = function (gitUrl, tmpDir) {
    tmpDir = tmpDir || tmp_1.default.dirSync().name;
    (0, child_process_1.execSync)(`git clone --quiet ${gitUrl} ${tmpDir}`, {
        env: process.env,
        cwd: process.cwd(),
    });
    return tmpDir;
};
exports.downloadRepo = downloadRepo;
function isGitUrl(gitUrl) {
    var regex = /(?:git|ssh|https?|git(lab)?@[-\w.]+):(\/\/)?(.*?)(\.git)(\/?|\#[-\d\w._]+?)$/;
    return regex.test(gitUrl);
}
exports.isGitUrl = isGitUrl;
;
